/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CommonMethodMetadata.java 2950 2008-04-25 09:14:23Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.scan.api.metadata.MethodMetadata;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * EZB common method metadata.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class CommonMethodMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends MethodMetadata<C, M, F> implements ICommonMethodMetadata<C, M, F> {

    /**
     * metadata common with class, field and method.
     */
    private CommonMetadata ejbJarCommonMetadata;

    /**
     * Constructor.
     * @param jMethod signature
     * @param classMetadata parent
     */
    public CommonMethodMetadata(final JMethod jMethod, final C classMetadata) {
        super(jMethod, classMetadata);
        this.ejbJarCommonMetadata = new CommonMetadata();
    }

    /**
     * @return JEjbEJB object representing javax.ejb.EJB annotation.
     */
    public final IJEjbEJB getJEjbEJB() {
        return this.ejbJarCommonMetadata.getJEjbEJB();
    }

    /**
     * Set JAnnotationEJB object.
     * @param jEjbEJB object representing javax.annotation.EJB annotation.
     */
    public final void setJEjbEJB(final IJEjbEJB jEjbEJB) {
        this.ejbJarCommonMetadata.setJEjbEJB(jEjbEJB);
    }

    /**
     * @return JAnnotationResource object representing javax.annotation.Resource
     *         annotation.
     */
    public final IJAnnotationResource getJAnnotationResource() {
        return this.ejbJarCommonMetadata.getJAnnotationResource();
    }

    /**
     * Set JAnnotationResource object.
     * @param jAnnotationResource object representing javax.annotation.Resource
     *        annotation.
     */
    public final void setJAnnotationResource(final IJAnnotationResource jAnnotationResource) {
        this.ejbJarCommonMetadata.setJAnnotationResource(jAnnotationResource);
    }

    /**
     * @return true if this field is used as a persistence context.
     */
    public final boolean isPersistenceContext() {
        return this.ejbJarCommonMetadata.isPersistenceContext();
    }

    /**
     * @return the persistence context infos.
     */
    public final IJavaxPersistenceContext getJavaxPersistenceContext() {
        return this.ejbJarCommonMetadata.getJavaxPersistenceContext();
    }

    /**
     * Sets the persistence context info on this field.
     * @param javaxPersistenceContext information on persistence context.
     */
    public final void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        this.ejbJarCommonMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * @return true if this field is used as a persistence unit.
     */
    public final boolean isPersistenceUnit() {
        return this.ejbJarCommonMetadata.isPersistenceUnit();
    }

    /**
     * @return the persistence unit infos.
     */
    public final IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return this.ejbJarCommonMetadata.getJavaxPersistenceUnit();
    }

    /**
     * Sets the persistence unit info on this field.
     * @param javaxPersistenceUnit information on persistence unit.
     */
    public final void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        this.ejbJarCommonMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

}
